searchData={"items":[{"type":"module","title":"PineUi","doc":"# Pine UI 🌲\n\nPine UI is a comprehensive collection of UI components for Phoenix applications,\nbuilt with AlpineJS and TailwindCSS. The library provides interactive, accessible,\nand customizable components to speed up development of modern web interfaces.","ref":"PineUi.html"},{"type":"module","title":"Installation - PineUi","doc":"Add Pine UI to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:pine_ui_phoenix, \"~> 0.1.0\"}\n  ]\nend\n```\n\nAfter running `mix deps.get`, make sure your project includes:\n\n1. **TailwindCSS** - For component styling\n2. **AlpineJS** - For component interactivity","ref":"PineUi.html#module-installation"},{"type":"module","title":"Component Categories - PineUi","doc":"Pine UI offers components organized in the following categories:\n\n#","ref":"PineUi.html#module-component-categories"},{"type":"module","title":"Text & Animation - PineUi","doc":"- `typing_effect/1` - Creates a typing animation with multiple text items\n- `text_animation_blow/1` - Letter-by-letter animation that scales in\n- `text_animation_fade/1` - Letter-by-letter fade-in animation\n\n#","ref":"PineUi.html#module-text-animation"},{"type":"module","title":"Interactive Elements - PineUi","doc":"- `tooltip/1` - Interactive tooltip with different positions\n- `button_primary/1`, `button_secondary/1`, `button_danger/1` - Button variants with loading states\n\n#","ref":"PineUi.html#module-interactive-elements"},{"type":"module","title":"Content Organization - PineUi","doc":"- `card/1` - Basic card component for content organization\n- `card_interactive/1` - Interactive card with hover effects\n- `card_collapsible/1` - Collapsible card for expandable content\n\n#","ref":"PineUi.html#module-content-organization"},{"type":"module","title":"Form Elements - PineUi","doc":"- `text_input/1` - Basic text input component\n- `text_input_with_icon/1` - Text input with icon\n- `textarea/1` - Multiline text input component\n- `select/1` - Basic select dropdown component\n- `select_grouped/1` - Select dropdown with option groups\n- `select_searchable/1` - Searchable select dropdown with filtering\n\n#","ref":"PineUi.html#module-form-elements"},{"type":"module","title":"Status Indicators - PineUi","doc":"- `badge/1` - Simple badge component with various colors\n- `badge_dot/1` - Badge with dot indicator\n- `badge_dismissible/1` - Badge that can be dismissed/removed","ref":"PineUi.html#module-status-indicators"},{"type":"module","title":"Basic Usage - PineUi","doc":"```heex\n \n   \n\n   \n     Pine UI makes it easy to build interactive Phoenix applications. \n\n     \n       \n        Get Started\n       \n\n       \n        Documentation\n       \n     \n   \n\n   \n \n```","ref":"PineUi.html#module-basic-usage"},{"type":"module","title":"Component Design Philosophy - PineUi","doc":"Pine UI components follow these principles:\n\n1. **Progressive Enhancement** - Components work without JavaScript but provide enhanced experiences when it's available\n2. **Accessibility Built-in** - ARIA attributes and keyboard navigation included by default\n3. **Tailwind-first** - Styled with TailwindCSS for easy customization and consistency\n4. **Alpine-powered** - Interactive behaviors handled by AlpineJS for minimal overhead\n5. **Phoenix-friendly** - Designed to work seamlessly with Phoenix and LiveView","ref":"PineUi.html#module-component-design-philosophy"},{"type":"module","title":"Customization - PineUi","doc":"Each component accepts class names that can be used to customize the appearance.\nCommon parameters include:\n\n- `:class` - Additional CSS classes for the main element\n- `:container_class` - CSS classes for the container element\n- `:variant` - For components with multiple style variants (success, warning, etc.)","ref":"PineUi.html#module-customization"},{"type":"module","title":"Accessibility - PineUi","doc":"Pine UI components are designed with accessibility in mind, following WCAG guidelines.\nComponents include appropriate ARIA roles, states, and properties where applicable.","ref":"PineUi.html#module-accessibility"},{"type":"function","title":"PineUi.badge/1","doc":"Renders a badge component.\n\n This component creates a simple badge with customizable colors.","ref":"PineUi.html#badge/1"},{"type":"function","title":"Examples - PineUi.badge/1","doc":"Completed\n     \n\n     \n      Pending","ref":"PineUi.html#badge/1-examples"},{"type":"function","title":"Options - PineUi.badge/1","doc":"* `:variant` - Color variant: \"success\", \"warning\", \"danger\", \"info\", \"purple\", \"pink\", \"indigo\", or \"default\" (gray)\n* `:class` - Additional CSS classes (optional)\n* `:icon` - HTML string for an icon to display before text (optional)","ref":"PineUi.html#badge/1-options"},{"type":"function","title":"PineUi.badge_dismissible/1","doc":"Renders a dismissible badge.\n\n This component creates a badge that can be removed/dismissed with a click.\nUses AlpineJS for the dismissal functionality.","ref":"PineUi.html#badge_dismissible/1"},{"type":"function","title":"Examples - PineUi.badge_dismissible/1","doc":"New Feature\n     \n\n     \n      Beta","ref":"PineUi.html#badge_dismissible/1-examples"},{"type":"function","title":"Options - PineUi.badge_dismissible/1","doc":"* `:variant` - Color variant: \"success\", \"warning\", \"danger\", \"info\", \"purple\", \"pink\", \"indigo\", or \"default\" (gray)\n* `:class` - Additional CSS classes (optional)","ref":"PineUi.html#badge_dismissible/1-options"},{"type":"function","title":"PineUi.badge_dot/1","doc":"Renders a badge with a status dot.\n\n This component creates a badge with a colored status dot at the beginning.","ref":"PineUi.html#badge_dot/1"},{"type":"function","title":"Examples - PineUi.badge_dot/1","doc":"Active\n     \n\n     \n      Offline","ref":"PineUi.html#badge_dot/1-examples"},{"type":"function","title":"Options - PineUi.badge_dot/1","doc":"* `:variant` - Color variant: \"success\", \"warning\", \"danger\", \"info\", \"purple\", \"pink\", \"indigo\", or \"default\" (gray)\n* `:class` - Additional CSS classes (optional)","ref":"PineUi.html#badge_dot/1-options"},{"type":"function","title":"PineUi.button_danger/1","doc":"Renders a danger button component with optional loading state.\n\n This component creates a danger/warning action button that can display a loading spinner\nand supports LiveView click events.","ref":"PineUi.html#button_danger/1"},{"type":"function","title":"Examples - PineUi.button_danger/1","doc":"Delete Item\n     \n\n     \n      Permanently Delete","ref":"PineUi.html#button_danger/1-examples"},{"type":"function","title":"Options - PineUi.button_danger/1","doc":"* `:type` - Button type attribute (optional, defaults to \"button\")\n* `:class` - Additional CSS classes (optional)\n* `:disabled` - Whether the button is disabled (optional, defaults to false)\n* `:loading` - Whether to show loading state (optional, defaults to false)\n* `:icon` - HTML string for an icon to display before text (optional)\n* `:phx_click` - The LiveView click event to trigger (optional)\n* `:phx_value_id` - The id value to pass with the event (optional)\n* `:phx_target` - The LiveView target for the event (optional)","ref":"PineUi.html#button_danger/1-options"},{"type":"function","title":"PineUi.button_primary/1","doc":"Renders a primary button component with optional loading state.\n\n This component creates a primary action button that can display a loading spinner\nand supports LiveView click events.","ref":"PineUi.html#button_primary/1"},{"type":"function","title":"Examples - PineUi.button_primary/1","doc":"Save Changes\n     \n\n     \n      Submit Form","ref":"PineUi.html#button_primary/1-examples"},{"type":"function","title":"Options - PineUi.button_primary/1","doc":"* `:type` - Button type attribute (optional, defaults to \"button\")\n* `:class` - Additional CSS classes (optional)\n* `:disabled` - Whether the button is disabled (optional, defaults to false)\n* `:loading` - Whether to show loading state (optional, defaults to false)\n* `:icon` - HTML string for an icon to display before text (optional)\n* `:phx_click` - The LiveView click event to trigger (optional)\n* `:phx_value_id` - The id value to pass with the event (optional)\n* `:phx_target` - The LiveView target for the event (optional)","ref":"PineUi.html#button_primary/1-options"},{"type":"function","title":"PineUi.button_secondary/1","doc":"Renders a secondary button component with optional loading state.\n\n This component creates a secondary action button that can display a loading spinner\nand supports LiveView click events.","ref":"PineUi.html#button_secondary/1"},{"type":"function","title":"Examples - PineUi.button_secondary/1","doc":"Cancel\n     \n\n     \n      View Details","ref":"PineUi.html#button_secondary/1-examples"},{"type":"function","title":"Options - PineUi.button_secondary/1","doc":"* `:type` - Button type attribute (optional, defaults to \"button\")\n* `:class` - Additional CSS classes (optional)\n* `:disabled` - Whether the button is disabled (optional, defaults to false)\n* `:loading` - Whether to show loading state (optional, defaults to false)\n* `:icon` - HTML string for an icon to display before text (optional)\n* `:phx_click` - The LiveView click event to trigger (optional)\n* `:phx_value_id` - The id value to pass with the event (optional)\n* `:phx_target` - The LiveView target for the event (optional)","ref":"PineUi.html#button_secondary/1-options"},{"type":"function","title":"PineUi.card/1","doc":"Renders a basic card component.\n\n This component creates a simple card container with optional title, subtitle, and footer.","ref":"PineUi.html#card/1"},{"type":"function","title":"Examples - PineUi.card/1","doc":"Card content goes here \n     \n\n     \n       \n         Multiple paragraphs can go here \n         With any content structure","ref":"PineUi.html#card/1-examples"},{"type":"function","title":"Options - PineUi.card/1","doc":"* `:title` - Card title text (optional)\n* `:subtitle` - Card subtitle text (optional)\n* `:footer` - Footer content (optional)\n* `:padded` - Whether to add padding to the body (optional, defaults to true)\n* `:class` - Additional CSS classes for the card container (optional)","ref":"PineUi.html#card/1-options"},{"type":"function","title":"PineUi.card_collapsible/1","doc":"Renders a collapsible card component.\n\n This component creates a card that can be expanded/collapsed when clicked.","ref":"PineUi.html#card_collapsible/1"},{"type":"function","title":"Examples - PineUi.card_collapsible/1","doc":"This content can be hidden or shown","ref":"PineUi.html#card_collapsible/1-examples"},{"type":"function","title":"Options - PineUi.card_collapsible/1","doc":"* `:title` - Card title text (optional)\n* `:subtitle` - Card subtitle text (optional)\n* `:footer` - Footer content (optional)\n* `:padded` - Whether to add padding to the body (optional, defaults to true)\n* `:open` - Whether the card is expanded on initial render (optional, defaults to false)\n* `:class` - Additional CSS classes for the card container (optional)","ref":"PineUi.html#card_collapsible/1-options"},{"type":"function","title":"PineUi.card_interactive/1","doc":"Renders an interactive card component with hover effects.\n\n This component creates a card that responds to hover with subtle animation.","ref":"PineUi.html#card_interactive/1"},{"type":"function","title":"Examples - PineUi.card_interactive/1","doc":"This card has hover effects","ref":"PineUi.html#card_interactive/1-examples"},{"type":"function","title":"Options - PineUi.card_interactive/1","doc":"* `:title` - Card title text (optional)\n* `:subtitle` - Card subtitle text (optional)\n* `:footer` - Footer content (optional)\n* `:padded` - Whether to add padding to the body (optional, defaults to true)\n* `:class` - Additional CSS classes for the card container (optional)","ref":"PineUi.html#card_interactive/1-options"},{"type":"function","title":"PineUi.select/1","doc":"Renders a basic select dropdown component.","ref":"PineUi.html#select/1"},{"type":"function","title":"Examples - PineUi.select/1","doc":"","ref":"PineUi.html#select/1-examples"},{"type":"function","title":"Options - PineUi.select/1","doc":"* `:id` - The ID for the select element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:options` - List of {value, label} tuples for the options (required)\n* `:selected` - The currently selected value (optional)\n* `:placeholder` - Placeholder text for empty selection (optional)\n* `:hint` - Help text displayed below the select (optional)\n* `:error` - Error message displayed below the select (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:class` - Additional CSS classes for the select element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.html#select/1-options"},{"type":"function","title":"PineUi.select_grouped/1","doc":"Renders a select dropdown with option groups.","ref":"PineUi.html#select_grouped/1"},{"type":"function","title":"Examples - PineUi.select_grouped/1","doc":"","ref":"PineUi.html#select_grouped/1-examples"},{"type":"function","title":"Options - PineUi.select_grouped/1","doc":"* `:id` - The ID for the select element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:option_groups` - List of {group_label, options} tuples where options is a list of {value, label} tuples (required)\n* `:selected` - The currently selected value (optional)\n* `:placeholder` - Placeholder text for empty selection (optional)\n* `:hint` - Help text displayed below the select (optional)\n* `:error` - Error message displayed below the select (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:class` - Additional CSS classes for the select element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.html#select_grouped/1-options"},{"type":"function","title":"PineUi.select_searchable/1","doc":"Renders a searchable select dropdown with filtering.","ref":"PineUi.html#select_searchable/1"},{"type":"function","title":"Examples - PineUi.select_searchable/1","doc":"","ref":"PineUi.html#select_searchable/1-examples"},{"type":"function","title":"Options - PineUi.select_searchable/1","doc":"* `:id` - The ID for the select element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:options` - List of {value, label} tuples for the options (required)\n* `:selected` - The currently selected value (optional)\n* `:selected_label` - The label for the currently selected value (optional, should match the label in options)\n* `:placeholder` - Placeholder text for the search input (optional)\n* `:hint` - Help text displayed below the select (optional)\n* `:error` - Error message displayed below the select (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:class` - Additional CSS classes for the select element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.html#select_searchable/1-options"},{"type":"function","title":"PineUi.text_animation_blow/1","doc":"Renders text with a scale animation where letters blow up into place.\n\n This component animates each letter of the text individually, starting from a\nlarger scale and shrinking into place.","ref":"PineUi.html#text_animation_blow/1"},{"type":"function","title":"Examples - PineUi.text_animation_blow/1","doc":"","ref":"PineUi.html#text_animation_blow/1-examples"},{"type":"function","title":"Options - PineUi.text_animation_blow/1","doc":"* `:text` - The text to animate (required, uses \"Pines UI Library\" if not provided)","ref":"PineUi.html#text_animation_blow/1-options"},{"type":"function","title":"PineUi.text_animation_fade/1","doc":"Renders text with a fade-in animation for each letter.\n\n This component animates each letter of the text individually with a fade-in effect,\ncreating a smooth appearance animation.","ref":"PineUi.html#text_animation_fade/1"},{"type":"function","title":"Examples - PineUi.text_animation_fade/1","doc":"","ref":"PineUi.html#text_animation_fade/1-examples"},{"type":"function","title":"Options - PineUi.text_animation_fade/1","doc":"* `:text` - The text to animate (required, uses \"Pines UI Library\" if not provided)","ref":"PineUi.html#text_animation_fade/1-options"},{"type":"function","title":"PineUi.text_input/1","doc":"Renders a basic text input component.","ref":"PineUi.html#text_input/1"},{"type":"function","title":"Examples - PineUi.text_input/1","doc":"","ref":"PineUi.html#text_input/1-examples"},{"type":"function","title":"Options - PineUi.text_input/1","doc":"* `:id` - The ID for the input element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:type` - Input type (optional, defaults to \"text\")\n* `:value` - Current input value (optional)\n* `:placeholder` - Placeholder text (optional)\n* `:prefix` - Text to display before the input (optional)\n* `:suffix` - Text to display after the input (optional)\n* `:hint` - Help text displayed below the input (optional)\n* `:error` - Error message displayed below the input (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:readonly` - Whether the field is read only (optional, defaults to false)\n* `:autofocus` - Whether the field should autofocus (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:phx_blur` - Phoenix blur event name (optional)\n* `:phx_focus` - Phoenix focus event name (optional)\n* `:phx_debounce` - Phoenix debounce setting (optional)\n* `:class` - Additional CSS classes for the input element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.html#text_input/1-options"},{"type":"function","title":"PineUi.text_input_with_icon/1","doc":"Renders a text input with an icon on the left.","ref":"PineUi.html#text_input_with_icon/1"},{"type":"function","title":"Examples - PineUi.text_input_with_icon/1","doc":"\"}\n    />","ref":"PineUi.html#text_input_with_icon/1-examples"},{"type":"function","title":"Options - PineUi.text_input_with_icon/1","doc":"* `:id` - The ID for the input element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:type` - Input type (optional, defaults to \"text\")\n* `:value` - Current input value (optional)\n* `:placeholder` - Placeholder text (optional)\n* `:icon` - SVG or HTML for the icon (required)\n* `:hint` - Help text displayed below the input (optional)\n* `:error` - Error message displayed below the input (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:readonly` - Whether the field is read only (optional, defaults to false)\n* `:autofocus` - Whether the field should autofocus (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:phx_blur` - Phoenix blur event name (optional)\n* `:phx_focus` - Phoenix focus event name (optional)\n* `:phx_debounce` - Phoenix debounce setting (optional)\n* `:class` - Additional CSS classes for the input element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.html#text_input_with_icon/1-options"},{"type":"function","title":"PineUi.textarea/1","doc":"Renders a textarea component for multiline text input.","ref":"PineUi.html#textarea/1"},{"type":"function","title":"Examples - PineUi.textarea/1","doc":"","ref":"PineUi.html#textarea/1-examples"},{"type":"function","title":"Options - PineUi.textarea/1","doc":"* `:id` - The ID for the textarea element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:value` - Current textarea value (optional)\n* `:placeholder` - Placeholder text (optional)\n* `:rows` - Number of visible rows (optional, defaults to 4)\n* `:hint` - Help text displayed below the textarea (optional)\n* `:error` - Error message displayed below the textarea (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:readonly` - Whether the field is read only (optional, defaults to false)\n* `:autofocus` - Whether the field should autofocus (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:phx_blur` - Phoenix blur event name (optional)\n* `:phx_debounce` - Phoenix debounce setting (optional)\n* `:class` - Additional CSS classes for the textarea element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.html#textarea/1-options"},{"type":"function","title":"PineUi.tooltip/1","doc":"Renders a customizable tooltip component.\n\n This component shows a tooltip when hovering over text. The tooltip can\nbe positioned at the top, left, or right of the trigger element.","ref":"PineUi.html#tooltip/1"},{"type":"function","title":"Examples - PineUi.tooltip/1","doc":"","ref":"PineUi.html#tooltip/1-examples"},{"type":"function","title":"Options - PineUi.tooltip/1","doc":"* `:title` - The text to display as the trigger (required, uses \"hover me\" if not provided)\n* `:description` - The tooltip text (required, uses \"Tooltip text\" if not provided)\n* `:type` - The tooltip position: \"top\" (default), \"left\", or \"right\"\n* `:class` - CSS classes to apply to the trigger element (optional)","ref":"PineUi.html#tooltip/1-options"},{"type":"function","title":"PineUi.typing_effect/1","doc":"Renders a typing effect component that cycles through a list of texts.\n\n This component creates a typewriter-like effect where text is typed out,\ndeleted, and replaced with the next text in the list.","ref":"PineUi.html#typing_effect/1"},{"type":"function","title":"Examples - PineUi.typing_effect/1","doc":"","ref":"PineUi.html#typing_effect/1-examples"},{"type":"function","title":"Options - PineUi.typing_effect/1","doc":"* `:text_list` - A JSON string array of texts to cycle through (required, will use defaults if not provided)\n* `:class` - CSS classes to apply to the container element (optional)\n* `:text_class` - CSS classes to apply to the text element (optional)","ref":"PineUi.html#typing_effect/1-options"},{"type":"module","title":"PineUi.Types","doc":"Type specifications for Pine UI components.\n\nThis module contains type specifications used throughout the library\nto provide better documentation and IDE support.","ref":"PineUi.Types.html"},{"type":"type","title":"PineUi.Types.assigns/0","doc":"Component default assigns.\n\nCommon assigns accepted by most components:\n- `:class` - Additional CSS classes\n- `:id` - DOM element ID\n- `:phx_*` - Phoenix LiveView specific attributes","ref":"PineUi.Types.html#t:assigns/0"},{"type":"type","title":"PineUi.Types.badge_assigns/0","doc":"Badge component assigns.\n\nAdditional assigns:\n- `:variant` - Color variant (success, warning, etc.)","ref":"PineUi.Types.html#t:badge_assigns/0"},{"type":"type","title":"PineUi.Types.button_assigns/0","doc":"Button component assigns.\n\nAdditional assigns:\n- `:loading` - Boolean to show loading state\n- `:disabled` - Boolean to disable the button\n- `:icon` - Optional icon markup","ref":"PineUi.Types.html#t:button_assigns/0"},{"type":"type","title":"PineUi.Types.card_assigns/0","doc":"Card component assigns.\n\nAdditional assigns:\n- `:title` - Optional card title\n- `:subtitle` - Optional card subtitle\n- `:footer` - Optional footer content\n- `:padded` - Boolean to add padding to content area","ref":"PineUi.Types.html#t:card_assigns/0"},{"type":"type","title":"PineUi.Types.select_assigns/0","doc":"Select component assigns.\n\nAdditional assigns:\n- `:options` - List of {value, label} tuples\n- `:selected` - Currently selected value\n- `:placeholder` - Placeholder text","ref":"PineUi.Types.html#t:select_assigns/0"},{"type":"type","title":"PineUi.Types.text_input_assigns/0","doc":"Text input component assigns.\n\nAdditional assigns:\n- `:label` - Optional input label\n- `:value` - Current input value\n- `:placeholder` - Placeholder text\n- `:required` - Boolean for required input\n- `:disabled` - Boolean to disable the input\n- `:hint` - Optional help text\n- `:error` - Optional error message","ref":"PineUi.Types.html#t:text_input_assigns/0"},{"type":"module","title":"PineUi.Button","doc":"Provides button components with various styles and states.\n\nThe Button module offers primary, secondary, and danger button variants\nwith support for loading states, icons, and Phoenix LiveView integration.","ref":"PineUi.Button.html"},{"type":"module","title":"Examples - PineUi.Button","doc":"Submit\n     \n\n     \n      Cancel\n     \n\n     \n      Delete","ref":"PineUi.Button.html#module-examples"},{"type":"module","title":"Accessibility - PineUi.Button","doc":"All button components provide proper focus states, ARIA attributes, and\nkeyboard interaction support.","ref":"PineUi.Button.html#module-accessibility"},{"type":"function","title":"PineUi.Button.danger/1","doc":"Renders a danger button component with optional loading state.\n\nDanger buttons should be used for destructive actions such as delete or remove.","ref":"PineUi.Button.html#danger/1"},{"type":"function","title":"Examples - PineUi.Button.danger/1","doc":"Delete Account \n\n     \n      Remove Item","ref":"PineUi.Button.html#danger/1-examples"},{"type":"function","title":"Options - PineUi.Button.danger/1","doc":"* `:type` - Button type attribute (optional, defaults to \"button\")\n* `:class` - Additional CSS classes (optional)\n* `:disabled` - Whether the button is disabled (optional, defaults to false)\n* `:loading` - Whether to show loading state (optional, defaults to false)\n* `:icon` - HTML string for an icon to display before text (optional)\n* `:phx_click` - The LiveView click event to trigger (optional)\n* `:phx_value_id` - The id value to pass with the event (optional)\n* `:phx_target` - The LiveView target for the event (optional)","ref":"PineUi.Button.html#danger/1-options"},{"type":"function","title":"PineUi.Button.primary/1","doc":"Renders a primary button component with optional loading state.","ref":"PineUi.Button.html#primary/1"},{"type":"function","title":"Examples - PineUi.Button.primary/1","doc":"Submit \n\n     \n      Save Changes\n     \n\n     \n      With Icon","ref":"PineUi.Button.html#primary/1-examples"},{"type":"function","title":"Options - PineUi.Button.primary/1","doc":"* `:type` - Button type attribute (optional, defaults to \"button\")\n* `:class` - Additional CSS classes (optional)\n* `:disabled` - Whether the button is disabled (optional, defaults to false)\n* `:loading` - Whether to show loading state (optional, defaults to false)\n* `:icon` - HTML string for an icon to display before text (optional)\n* `:phx_click` - The LiveView click event to trigger (optional)\n* `:phx_value_id` - The id value to pass with the event (optional)\n* `:phx_target` - The LiveView target for the event (optional)","ref":"PineUi.Button.html#primary/1-options"},{"type":"function","title":"PineUi.Button.secondary/1","doc":"Renders a secondary button component with optional loading state.\n\nSecondary buttons are often used for secondary actions or alternative options.","ref":"PineUi.Button.html#secondary/1"},{"type":"function","title":"Examples - PineUi.Button.secondary/1","doc":"Cancel \n\n     \n      Go Back","ref":"PineUi.Button.html#secondary/1-examples"},{"type":"function","title":"Options - PineUi.Button.secondary/1","doc":"* `:type` - Button type attribute (optional, defaults to \"button\")\n* `:class` - Additional CSS classes (optional)\n* `:disabled` - Whether the button is disabled (optional, defaults to false)\n* `:loading` - Whether to show loading state (optional, defaults to false)\n* `:icon` - HTML string for an icon to display before text (optional)\n* `:phx_click` - The LiveView click event to trigger (optional)\n* `:phx_value_id` - The id value to pass with the event (optional)\n* `:phx_target` - The LiveView target for the event (optional)","ref":"PineUi.Button.html#secondary/1-options"},{"type":"module","title":"PineUi.Card","doc":"Provides card components for organizing content with various behaviors.\n\nThe Card module offers three main variants:\n\n- `basic/1` - Simple card with title, subtitle, content area, and optional footer\n- `interactive/1` - Card with hover animation effects\n- `collapsible/1` - Expandable/collapsible card with toggle functionality","ref":"PineUi.Card.html"},{"type":"module","title":"Examples - PineUi.Card","doc":"Card content here \n     \n\n     \n       This card has hover effects \n     \n\n     \n       This content can be hidden","ref":"PineUi.Card.html#module-examples"},{"type":"module","title":"Styling - PineUi.Card","doc":"Cards use TailwindCSS for styling and can be customized using the `class` parameter.","ref":"PineUi.Card.html#module-styling"},{"type":"function","title":"PineUi.Card.basic/1","doc":"Renders a basic card component.","ref":"PineUi.Card.html#basic/1"},{"type":"function","title":"Examples - PineUi.Card.basic/1","doc":"Content goes here \n     \n\n     \n       Content goes here","ref":"PineUi.Card.html#basic/1-examples"},{"type":"function","title":"Options - PineUi.Card.basic/1","doc":"* `:title` - Card title text (optional)\n* `:subtitle` - Card subtitle text (optional)\n* `:footer` - Footer content (optional)\n* `:padded` - Whether to add padding to the body (optional, defaults to true)\n* `:class` - Additional CSS classes for the card container (optional)","ref":"PineUi.Card.html#basic/1-options"},{"type":"function","title":"PineUi.Card.collapsible/1","doc":"Renders a collapsible card component with expand/collapse functionality.\n\nThis card can be toggled between expanded and collapsed states by clicking\non the header. Uses AlpineJS for the toggle functionality.","ref":"PineUi.Card.html#collapsible/1"},{"type":"function","title":"Examples - PineUi.Card.collapsible/1","doc":"This content can be hidden \n     \n\n     \n       This content is visible by default","ref":"PineUi.Card.html#collapsible/1-examples"},{"type":"function","title":"Options - PineUi.Card.collapsible/1","doc":"* `:title` - Card title text (optional)\n* `:subtitle` - Card subtitle text (optional)\n* `:footer` - Footer content (optional)\n* `:padded` - Whether to add padding to the body (optional, defaults to true)\n* `:open` - Whether the card is expanded on initial render (optional, defaults to false)\n* `:class` - Additional CSS classes for the card container (optional)","ref":"PineUi.Card.html#collapsible/1-options"},{"type":"function","title":"PineUi.Card.interactive/1","doc":"Renders an interactive card component with hover effects.\n\nThis card variant adds subtle animation effects when hovered,\nmaking it ideal for clickable cards or emphasizing important content.","ref":"PineUi.Card.html#interactive/1"},{"type":"function","title":"Examples - PineUi.Card.interactive/1","doc":"Hover over me to see effects \n     \n\n     \n       Content with hover effects","ref":"PineUi.Card.html#interactive/1-examples"},{"type":"function","title":"Options - PineUi.Card.interactive/1","doc":"* `:title` - Card title text (optional)\n* `:subtitle` - Card subtitle text (optional)\n* `:footer` - Footer content (optional)\n* `:padded` - Whether to add padding to the body (optional, defaults to true)\n* `:class` - Additional CSS classes for the card container (optional)","ref":"PineUi.Card.html#interactive/1-options"},{"type":"module","title":"PineUi.Select","doc":"Provides select components for dropdown selections.\n\nThe Select module offers three main variants:\n- `basic/1` - Standard select dropdown\n- `grouped/1` - Select with option groups\n- `searchable/1` - Enhanced select with search functionality","ref":"PineUi.Select.html"},{"type":"function","title":"PineUi.Select.basic/1","doc":"Renders a basic select dropdown component.","ref":"PineUi.Select.html#basic/1"},{"type":"function","title":"Examples - PineUi.Select.basic/1","doc":"","ref":"PineUi.Select.html#basic/1-examples"},{"type":"function","title":"Options - PineUi.Select.basic/1","doc":"* `:id` - The ID for the select element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:options` - List of {value, label} tuples for the options (required)\n* `:selected` - The currently selected value (optional)\n* `:placeholder` - Placeholder text for empty selection (optional)\n* `:hint` - Help text displayed below the select (optional)\n* `:error` - Error message displayed below the select (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:class` - Additional CSS classes for the select element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.Select.html#basic/1-options"},{"type":"function","title":"PineUi.Select.grouped/1","doc":"Renders a select dropdown with option groups.","ref":"PineUi.Select.html#grouped/1"},{"type":"function","title":"Examples - PineUi.Select.grouped/1","doc":"","ref":"PineUi.Select.html#grouped/1-examples"},{"type":"function","title":"Options - PineUi.Select.grouped/1","doc":"* `:id` - The ID for the select element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:option_groups` - List of {group_label, options} tuples (required)\n* `:selected` - The currently selected value (optional)\n* `:placeholder` - Placeholder text for empty selection (optional)\n* `:hint` - Help text displayed below the select (optional)\n* `:error` - Error message displayed below the select (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:class` - Additional CSS classes for the select element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.Select.html#grouped/1-options"},{"type":"function","title":"PineUi.Select.searchable/1","doc":"Renders a searchable select dropdown with filtering.","ref":"PineUi.Select.html#searchable/1"},{"type":"function","title":"Examples - PineUi.Select.searchable/1","doc":"","ref":"PineUi.Select.html#searchable/1-examples"},{"type":"function","title":"Options - PineUi.Select.searchable/1","doc":"* `:id` - The ID for the select element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:options` - List of {value, label} tuples for the options (required)\n* `:selected` - The currently selected value (optional)\n* `:selected_label` - The label for the selected value (optional)\n* `:placeholder` - Placeholder text for the search (optional)\n* `:hint` - Help text displayed below the select (optional)\n* `:error` - Error message displayed below the select (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:class` - Additional CSS classes for the select element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.Select.html#searchable/1-options"},{"type":"module","title":"PineUi.TextInput","doc":"Provides text input components for forms and user input.\n\nThe TextInput module offers three main variants:\n\n- `basic/1` - Standard text input with optional prefix/suffix\n- `with_icon/1` - Text input with an icon\n- `textarea/1` - Multiline text input\n\nAll text input components support labels, hints, error messages, and\nare fully integrated with Phoenix LiveView.","ref":"PineUi.TextInput.html"},{"type":"module","title":"Examples - PineUi.TextInput","doc":"... \"}\n      placeholder=\"Search...\"\n    />","ref":"PineUi.TextInput.html#module-examples"},{"type":"module","title":"Accessibility - PineUi.TextInput","doc":"All text input components include proper labeling, focus styles, and\nARIA attributes for accessibility.","ref":"PineUi.TextInput.html#module-accessibility"},{"type":"function","title":"PineUi.TextInput.basic/1","doc":"Renders a basic text input component.\n\nThis component supports various input types and can include prefix/suffix\ntext alongside the input.","ref":"PineUi.TextInput.html#basic/1"},{"type":"function","title":"Examples - PineUi.TextInput.basic/1","doc":"","ref":"PineUi.TextInput.html#basic/1-examples"},{"type":"function","title":"Options - PineUi.TextInput.basic/1","doc":"* `:id` - The ID for the input element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:type` - Input type (optional, defaults to \"text\")\n* `:value` - Current input value (optional)\n* `:placeholder` - Placeholder text (optional)\n* `:prefix` - Text to display before the input (optional)\n* `:suffix` - Text to display after the input (optional)\n* `:hint` - Help text displayed below the input (optional)\n* `:error` - Error message displayed below the input (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:readonly` - Whether the field is read only (optional, defaults to false)\n* `:autofocus` - Whether the field should autofocus (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:phx_blur` - Phoenix blur event name (optional)\n* `:phx_focus` - Phoenix focus event name (optional)\n* `:phx_debounce` - Phoenix debounce setting (optional)\n* `:class` - Additional CSS classes for the input element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.TextInput.html#basic/1-options"},{"type":"function","title":"PineUi.TextInput.textarea/1","doc":"Renders a textarea component for multiline text input.","ref":"PineUi.TextInput.html#textarea/1"},{"type":"function","title":"Examples - PineUi.TextInput.textarea/1","doc":"","ref":"PineUi.TextInput.html#textarea/1-examples"},{"type":"function","title":"Options - PineUi.TextInput.textarea/1","doc":"* `:id` - The ID for the textarea element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:value` - Current textarea value (optional)\n* `:placeholder` - Placeholder text (optional)\n* `:rows` - Number of visible rows (optional, defaults to 4)\n* `:hint` - Help text displayed below the textarea (optional)\n* `:error` - Error message displayed below the textarea (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:readonly` - Whether the field is read only (optional, defaults to false)\n* `:autofocus` - Whether the field should autofocus (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:phx_blur` - Phoenix blur event name (optional)\n* `:phx_debounce` - Phoenix debounce setting (optional)\n* `:class` - Additional CSS classes for the textarea element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.TextInput.html#textarea/1-options"},{"type":"function","title":"PineUi.TextInput.with_icon/1","doc":"Renders a text input with an icon on the left side.\n\nThis component is ideal for search inputs or any field that benefits from\na visual indicator of its purpose.","ref":"PineUi.TextInput.html#with_icon/1"},{"type":"function","title":"Examples - PineUi.TextInput.with_icon/1","doc":"\"}\n      placeholder=\"Search...\"\n    />\n\n     ... \"}\n      label=\"Email\"\n      error={@form.errors[:email]}\n    />","ref":"PineUi.TextInput.html#with_icon/1-examples"},{"type":"function","title":"Options - PineUi.TextInput.with_icon/1","doc":"* `:id` - The ID for the input element (required)\n* `:name` - The name attribute (optional, defaults to ID)\n* `:label` - Label text (optional)\n* `:icon` - The icon to display (required, as HEEx or HTML string)\n* `:type` - Input type (optional, defaults to \"text\")\n* `:value` - Current input value (optional)\n* `:placeholder` - Placeholder text (optional)\n* `:hint` - Help text displayed below the input (optional)\n* `:error` - Error message displayed below the input (optional)\n* `:required` - Whether the field is required (optional, defaults to false)\n* `:disabled` - Whether the field is disabled (optional, defaults to false)\n* `:readonly` - Whether the field is read only (optional, defaults to false)\n* `:autofocus` - Whether the field should autofocus (optional, defaults to false)\n* `:phx_change` - Phoenix change event name (optional)\n* `:phx_blur` - Phoenix blur event name (optional)\n* `:phx_focus` - Phoenix focus event name (optional)\n* `:phx_debounce` - Phoenix debounce setting (optional)\n* `:class` - Additional CSS classes for the input element (optional)\n* `:container_class` - CSS classes for the container div (optional)","ref":"PineUi.TextInput.html#with_icon/1-options"},{"type":"module","title":"PineUi.Badge","doc":"Provides badge components for status indicators.\n\nThe Badge module offers several variants for indicating status:\n- `base/1` - Simple colored badge\n- `dot/1` - Badge with a status dot\n- `dismissible/1` - Badge that can be dismissed","ref":"PineUi.Badge.html"},{"type":"function","title":"PineUi.Badge.base/1","doc":"Renders a basic badge component.","ref":"PineUi.Badge.html#base/1"},{"type":"function","title":"Examples - PineUi.Badge.base/1","doc":"Completed \n\n     Pending","ref":"PineUi.Badge.html#base/1-examples"},{"type":"function","title":"Options - PineUi.Badge.base/1","doc":"* `:variant` - Color variant: \"success\", \"warning\", \"danger\", \"info\", \"purple\", \"pink\", \"indigo\", or \"default\" (gray)\n* `:class` - Additional CSS classes (optional)\n* `:icon` - HTML string for an icon to display before text (optional)","ref":"PineUi.Badge.html#base/1-options"},{"type":"function","title":"PineUi.Badge.dismissible/1","doc":"Renders a dismissible badge.","ref":"PineUi.Badge.html#dismissible/1"},{"type":"function","title":"Examples - PineUi.Badge.dismissible/1","doc":"New Feature \n\n     Beta","ref":"PineUi.Badge.html#dismissible/1-examples"},{"type":"function","title":"Options - PineUi.Badge.dismissible/1","doc":"* `:variant` - Color variant: \"success\", \"warning\", \"danger\", \"info\", \"purple\", \"pink\", \"indigo\", or \"default\" (gray)\n* `:class` - Additional CSS classes (optional)","ref":"PineUi.Badge.html#dismissible/1-options"},{"type":"function","title":"PineUi.Badge.dot/1","doc":"Renders a badge with a status dot.","ref":"PineUi.Badge.html#dot/1"},{"type":"function","title":"Examples - PineUi.Badge.dot/1","doc":"Active \n\n     Offline","ref":"PineUi.Badge.html#dot/1-examples"},{"type":"function","title":"Options - PineUi.Badge.dot/1","doc":"* `:variant` - Color variant: \"success\", \"warning\", \"danger\", \"info\", \"purple\", \"pink\", \"indigo\", or \"default\" (gray)\n* `:class` - Additional CSS classes (optional)","ref":"PineUi.Badge.html#dot/1-options"},{"type":"extras","title":"Overview","doc":"# Pine UI\n\n[![Tailwind CSS](https://img.shields.io/badge/Tailwind_CSS-38B2AC?style=for-the-badge&logo=tailwind-css&logoColor=white)]()\n[![Phoenix Framework](https://img.shields.io/badge/Phoenix_Framework-FD4F00?style=for-the-badge&logo=elixir&logoColor=white)]()\n[![AlpineJS](https://img.shields.io/badge/AlpineJS-8BC0D0?style=for-the-badge&logo=alpinejs&logoColor=white)]()\n\nA comprehensive library of interactive UI components for Phoenix applications built with AlpineJS and TailwindCSS.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"Add Pine UI to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:pine_ui_phoenix, \"~> 0.1.1\"}\n  ]\nend\n```\n\nAfter running `mix deps.get`, make sure your project includes:\n\n1. **TailwindCSS** - For component styling\n2. **AlpineJS** - For component interactivity","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Overview","doc":"Pine UI provides a collection of Phoenix Components that can be used in your HEEx templates. Each component is designed to be customizable and works well with Phoenix LiveView.\n\n```heex\n \n   \n  \n   \n     Pine UI makes it easy to build interactive Phoenix applications. \n    \n     \n       \n        Get Started\n       \n      \n       \n        Documentation\n       \n     \n   \n  \n   \n \n```","ref":"readme.html#usage"},{"type":"extras","title":"Available Components - Overview","doc":"#","ref":"readme.html#available-components"},{"type":"extras","title":"Text & Animation - Overview","doc":"- `typing_effect/1` - Creates a typing animation with multiple text items\n- `text_animation_blow/1` - Letter-by-letter animation that scales in\n- `text_animation_fade/1` - Letter-by-letter fade-in animation\n\n#","ref":"readme.html#text-animation"},{"type":"extras","title":"Interactive Elements - Overview","doc":"- `tooltip/1` - Interactive tooltip with different positions (top, left, right)\n- `button_primary/1` - Primary action button with loading state\n- `button_secondary/1` - Secondary action button with loading state\n- `button_danger/1` - Danger action button with loading state\n\n#","ref":"readme.html#interactive-elements"},{"type":"extras","title":"Content Organization - Overview","doc":"- `card/1` - Basic card component for content organization\n- `card_interactive/1` - Interactive card with hover effects\n- `card_collapsible/1` - Collapsible card for expandable content\n\n#","ref":"readme.html#content-organization"},{"type":"extras","title":"Form Elements - Overview","doc":"- `text_input/1` - Basic text input component\n- `text_input_with_icon/1` - Text input with icon\n- `textarea/1` - Multiline text input component\n- `select/1` - Basic select dropdown component\n- `select_grouped/1` - Select dropdown with option groups\n- `select_searchable/1` - Searchable select dropdown with filtering\n\n#","ref":"readme.html#form-elements"},{"type":"extras","title":"Status Indicators - Overview","doc":"- `badge/1` - Simple badge component with various colors\n- `badge_dot/1` - Badge with dot indicator\n- `badge_dismissible/1` - Badge that can be dismissed/removed","ref":"readme.html#status-indicators"},{"type":"extras","title":"Component Examples - Overview","doc":"#","ref":"readme.html#component-examples"},{"type":"extras","title":"Text Animation - Overview","doc":"```heex\n \n\n \n\n \n```\n\n#","ref":"readme.html#text-animation"},{"type":"extras","title":"Buttons - Overview","doc":"```heex\n \n  Save Changes\n \n\n \n  Loading Example\n \n\n \n  Delete\n \n```\n\n#","ref":"readme.html#buttons"},{"type":"extras","title":"Cards - Overview","doc":"```heex\n \n   Content goes here \n \n\n \n   This card has hover effects \n \n\n \n   This content can be collapsed \n \n```\n\n#","ref":"readme.html#cards"},{"type":"extras","title":"Form Inputs - Overview","doc":"```heex\n \n\n   \"}\n/>\n\n \n```\n\n#","ref":"readme.html#form-inputs"},{"type":"extras","title":"Select Inputs - Overview","doc":"```heex\n \n\n \n\n \n```\n\n#","ref":"readme.html#select-inputs"},{"type":"extras","title":"Badges - Overview","doc":"```heex\n \n  Completed\n \n\n \n  Pending\n \n\n \n  New Feature\n \n```","ref":"readme.html#badges"},{"type":"extras","title":"Roadmap - Overview","doc":"Future components and enhancements:\n\n- [ ] Alert component variants\n- [ ] Avatar with status indicators\n- [ ] Toggle/switch component\n- [ ] Tabs component\n- [ ] Dropdown menu\n- [ ] Table component with sorting and pagination\n- [ ] Accordion component\n- [ ] Progress bar\n- [ ] Modal dialog\n- [ ] Date picker","ref":"readme.html#roadmap"},{"type":"extras","title":"License - Overview","doc":"This project is licensed under the MIT License - see the LICENSE file for details.","ref":"readme.html#license"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2023 James Njovu\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}